@@ -1,9 +1,9 @@
 from typing import Callable
 
 import htmlgenerator as hg
-from bread import layout
-from bread.layout.components.datatable import DataTableColumn
-from bread.utils import Link, ModelHref, reverse_model
+from basxbread import layout
+from basxbread.layout.components.datatable import DataTableColumn
+from basxbread.utils import Link, ModelHref, reverse_model
 from django.shortcuts import get_object_or_404
 from django.utils.translation import gettext_lazy as _
 
